@@ -31,13 +31,13 @@ async def job(trainml):
 class JobLifeCycleTests:
     async def test_wait_for_running(self, job):
         assert job.status != "running"
-        job = await job.wait_for("running", 120)
+        job = await job.wait_for("running", 180)
         assert job.status == "running"
 
     async def test_stop_job(self, job):
         assert job.status == "running"
         await job.stop()
-        job = await job.wait_for("stopped", 60)
+        job = await job.wait_for("stopped", 120)
         assert job.status == "stopped"
 
     async def test_get_jobs(self, trainml, job):
@@ -52,7 +52,6 @@ class JobLifeCycleTests:
         assert isinstance(job.id, str)
         assert isinstance(job.name, str)
         assert isinstance(job.status, str)
-        assert isinstance(job.provider, str)
         assert isinstance(job.type, str)
 
     def test_job_str(self, job):
@@ -76,7 +75,7 @@ class JobLifeCycleTests:
     async def test_copy_job(self, job):
         job_copy = await job.copy("CLI Automated Job Copy")
         assert job_copy.id != job.id
-        await job_copy.wait_for("running", 120)
+        await job_copy.wait_for("running", 300)
         assert job_copy.status == "running"
         await job_copy.stop()
         await job_copy.wait_for("stopped", 60)
@@ -102,7 +101,7 @@ class JobLifeCycleTests:
             ),
         )
         assert training_job.id
-        training_job = await training_job.wait_for("finished", 180)
+        training_job = await training_job.wait_for("finished", 300)
         assert training_job.status == "finished"
         assert training_job.credits > 0
         assert training_job.credits < 0.1
@@ -119,7 +118,7 @@ class JobLifeCycleTests:
 
 @mark.create
 @mark.asyncio
-class JobFeatureTests:
+class JobIOTests:
     async def test_job_local_output(self, trainml, capsys):
         temp_dir = tempfile.TemporaryDirectory()
         job = await trainml.jobs.create(
@@ -227,6 +226,10 @@ class JobFeatureTests:
         )
         await new_model.remove()
 
+
+@mark.create
+@mark.asyncio
+class JobTypeTests:
     async def test_endpoint(self, trainml):
         job = await trainml.jobs.create(
             "CLI Automated Endpoint",
