@@ -43,11 +43,11 @@ def job(mock_trainml):
                 }
             ],
             "worker_status": "new",
-            "provider": "trainml",
             "resources": {
                 "gpu_count": 1,
                 "gpu_type_id": "1060-id",
                 "disk_size": 10,
+                "max_price": 10,
             },
             "model": {
                 "size": 7176192,
@@ -118,11 +118,11 @@ def training_job(mock_trainml):
                 }
             ],
             "worker_status": "running",
-            "provider": "trainml",
             "resources": {
                 "gpu_count": 1,
                 "gpu_type_id": "1060-id",
                 "disk_size": 10,
+                "max_price": 10,
             },
             "model": {
                 "size": 7176192,
@@ -276,9 +276,7 @@ class JobsTests:
             name="job_name",
             type="notebook",
             resources=dict(
-                gpu_type_id="GTX 1060",
-                gpu_count=1,
-                disk_size=10,
+                gpu_type_id="GTX 1060", gpu_count=1, disk_size=10, max_price=10
             ),
             environment=dict(type="DEEPLEARNING_PY38"),
             model=dict(),
@@ -303,6 +301,7 @@ class JobsTests:
             gpu_type="1060-id",
             gpu_count=1,
             disk_size=10,
+            max_price=2,
             worker_commands=None,
             environment=None,
             data=None,
@@ -312,9 +311,7 @@ class JobsTests:
             name="job_name",
             type="notebook",
             resources=dict(
-                gpu_type_id="1060-id",
-                gpu_count=1,
-                disk_size=10,
+                gpu_type_id="1060-id", gpu_count=1, disk_size=10, max_price=2
             ),
             source_job_uuid="job-id-1",
         )
@@ -332,7 +329,6 @@ class JobTests:
         assert isinstance(job.id, str)
         assert isinstance(job.name, str)
         assert isinstance(job.status, str)
-        assert isinstance(job.provider, str)
         assert isinstance(job.type, str)
 
     def test_job_str(self, job):
@@ -412,7 +408,6 @@ class JobTests:
                 "name": "test notebook",
                 "type": "notebook",
                 "status": "new",
-                "provider": "trainml",
                 "model": {},
                 "data": {
                     "datasets": [],
@@ -453,7 +448,6 @@ class JobTests:
                 "name": "test notebook",
                 "type": "notebook",
                 "status": "new",
-                "provider": "trainml",
                 "model": {"source_type": "local", "source_uri": "~/model_dir"},
                 "data": {
                     "datasets": [],
@@ -679,6 +673,7 @@ class JobTests:
             "gpu_type": "1060-id",
             "gpu_count": 1,
             "disk_size": 10,
+            "max_price": 10,
             "worker_commands": None,
             "workers": None,
             "environment": None,
