@@ -69,6 +69,7 @@ class Jobs(object):
         gpu_type,
         gpu_count,
         disk_size,
+        max_price=10,
         worker_commands=[],
         environment=dict(type="DEEPLEARNING_PY38"),
         data=dict(),
@@ -88,6 +89,7 @@ class Jobs(object):
                 gpu_type_id=gpu_type,
                 gpu_count=gpu_count,
                 disk_size=disk_size,
+                max_price=max_price,
             ),
             worker_commands=worker_commands,
             workers=kwargs.get("workers"),
@@ -130,7 +132,6 @@ class Job:
         self._job = kwargs
         self._id = self._job.get("id", self._job.get("job_uuid"))
         self._name = self._job.get("name")
-        self._provider = self._job.get("provider")
         self._status = self._job.get("status")
         self._type = self._job.get("type")
         self._workers = self._job.get("workers")
@@ -152,10 +153,6 @@ class Job:
     def status(self) -> str:
         return self._status
 
-    @property
-    def provider(self) -> str:
-        return self._provider
-
     @property
     def type(self) -> str:
         return self._type
@@ -197,7 +194,13 @@ class Job:
             "environment",
             "workers",
         ]
-        resources_keys = ["gpu_count", "gpu_type_id", "disk_size"]
+        resources_keys = [
+            "gpu_count",
+            "gpu_type_id",
+            "disk_size",
+            "max_price",
+            "preemptible",
+        ]
         model_keys = ["git_uri", "model_uuid"]
         data_keys = [
             "datasets",
@@ -329,6 +332,7 @@ class Job:
             w.get("job_worker_uuid"): ind + 1
             for ind, w in enumerate(self._workers)
         }
+        worker_numbers["data_worker"] = 0
 
         def handler(data):
             if data.get("type") == "subscription":
@@ -381,6 +385,8 @@ class Job:
             or self._job.get("resources").get("gpu_count"),
             disk_size=kwargs.get("disk_size")
             or self._job.get("resources").get("disk_size"),
+            max_price=kwargs.get("max_price")
+            or self._job.get("resources").get("max_price"),
             worker_commands=kwargs.get("worker_commands"),
             workers=kwargs.get("workers"),
             environment=kwargs.get("environment"),
